@@ -8,7 +8,7 @@ BigInt &BigInt::checked4(int (*BN_op)(BIGNUM *,
     BNCTX ctx;
 
     if ((*BN_op)(&d_bn, &d_bn, &rhs.d_bn, ctx) != 1)
-        throw Errno("BigInt ") << op << " failed";
+        throw Exception() << "BigInt " << op << " failed";
 
     return *this;
 }
