@@ -5,7 +5,7 @@ BigInt &BigInt::operator*=(BigInt const &rhs)
     BNCTX ctx;
 
     if (BN_mul(&d_bn, &d_bn, &rhs.d_bn, ctx) == 0)
-        throw Errno("BigInt *= failed");
+        throw Exception() << "BigInt *= failed";
 
     return *this;
 }
