@@ -3,14 +3,14 @@
 void Fork::fork()
 {
     if ((d_pid = ::fork()) < 0)
-        throw Errno("Fork::fork()");
+        throw Exception() << "Fork::fork(): " << errnodescr;
 
     if (d_pid == 0)         // childprocess has pid == 0
     {
         childRedirections();
         childProcess();
 
-        exit (1);           // we shouldn't come here: childProcess should
+        throw Exception(1); // we shouldn't come here: childProcess should
                             // exit
     }
 
